@@ -1,6 +1,6 @@
 import os
 from collections import OrderedDict
-from typing import List, Optional, Iterable
+from typing import List, Optional, Sequence, TYPE_CHECKING
 from django.conf import settings
 from django.conf.urls import url
 from django.contrib import admin
@@ -170,7 +170,7 @@ class AdminLogEntryMixin:
     Call fields_changed() on change events.
     """
 
-    def fields_changed(self, field_names: list, who: User, **kw):
+    def fields_changed(self, field_names: Sequence[str], who: Optional[User], **kw):
         fv_str = ''
         for k in field_names:
             label, value = get_model_field_label_and_value(self, k)
@@ -192,10 +192,17 @@ class AdminFileDownloadMixin:
     """
     upload_to = 'uploads'
     file_field = 'file'
-    file_fields: Iterable[str] = []
+    file_fields: Sequence[str] = []
     is_staff_to_download = True
     is_authenticated_to_download = True
 
+    if TYPE_CHECKING:
+        def get_queryset(self, request):
+            pass
+
+        def get_object(self, request, object_id, from_field=None):
+            pass
+
     def get_file_fields(self) -> List[str]:
         if self.file_fields and self.file_field:
             raise AssertionError('AdminFileDownloadMixin cannot have both file_fields and '
@@ -270,7 +277,7 @@ class AdminFileDownloadMixin:
 
         Returns: File download URLs for this model.
         """
-        info = self.model._meta.app_label, self.model._meta.model_name  # pytype: disable=attribute-error
+        info = self.model._meta.app_label, self.model._meta.model_name  # type: ignore  # pytype: disable=attribute-error
         return [
             url(r'^\d+/change/(' + self.upload_to + '/.+)/$', self.file_download_view, name='%s_%s_file_download' % info),
             url(r'^(' + self.upload_to + '/.+)/$', self.file_download_view, name='%s_%s_file_download_changelist' % info),
